# Alpha houses all of our containerized applications
# Essentially it is a cluster with services that we
# choose to expose to the internet in one form or another




# Alpha cluster definition 
###########################
resource "aws_ecs_cluster" "alpha" {
  name = "${var.athens_prefix}-athens-alpha"
  configuration {
    execute_command_configuration {
      logging = "OVERRIDE"
      log_configuration {
        cloud_watch_log_group_name = aws_cloudwatch_log_group.alpha.name
      }
    }
  }
}


# Lewdlad Task Definition
# This is what the service will launch to actually provide the lewdlad service
##############################################################################
resource "aws_ecs_task_definition" "sample" {
  family = "${var.athens_prefix}-sample"

  network_mode = "awsvpc"
  requires_compatibilities = ["FARGATE"]
  execution_role_arn = aws_iam_role.alpha_iam_role.arn

  cpu = 256
  memory = 512

  container_definitions = jsonencode([
    {
      name = "${var.athens_prefix}-sample-container"
      image = "nginx"
      cpu = 256
      memory = 512
      essential = true
      portMappings = [
        {
          containerPort = 80
          hostPort = 80
        }
      ]
      logConfiguration = {
        logDriver = "awslogs"
        options = {
          awslogs-group  = aws_cloudwatch_log_group.alpha.name
          awslogs-region = "us-west-1"
          awslogs-stream-prefix  = "sample-container"
        }
      }
    }
  ])
  tags = {
    Name = "${var.athens_prefix}-sample-task-def-container"
  }
}

# Service level definition
##########################
resource "aws_ecs_service" "sample" {
  name            = "${var.athens_prefix}-sample-service"
  cluster         = aws_ecs_cluster.alpha.id
  task_definition = aws_ecs_task_definition.sample.arn
  desired_count   = 1
  launch_type = "FARGATE"
  load_balancer {
    target_group_arn = aws_lb_target_group.alpha_cluster.arn
    container_name = "${var.athens_prefix}-sample-container"
    container_port = 80
  }

  network_configuration {
    assign_public_ip = true
    subnets          = [
      aws_subnet.delphi.id,
      aws_subnet.crete_subnet.id
    ]
    security_groups  = [ 
      aws_security_group.ecs_web_ingress.id,
      aws_security_group.base_ecs.id
    ]
  }
}
